MethodChannelFlutterNsfwDetector class
An implementation of FlutterNsfwDetectorPlatform that uses method channels.
- Inheritance
-
- Object
- PlatformInterface
- FlutterNsfwDetectorPlatform
- MethodChannelFlutterNsfwDetector
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- methodChannel → MethodChannel
-
The method channel used to interact with the native platform.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
initialize(
) → Future< void> -
Initialize the native ML engine.
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
scanImageBytes(
List< int> bytes) → Future<Map< String, dynamic> > -
Scan image bytes and return the raw result map.
override
-
scanImageFile(
File file) → Future< Map< String, dynamic> > -
Scan an image file and return the raw result map.
override
-
scanVideoFile(
File file, int frameCount, double threshold) → Future< Map< String, dynamic> > -
Scan a video file by extracting
frameCountframes, usingthresholdfor fail-fast.override -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited